Enum ConnectionStatus
#[non_exhaustive]pub enum ConnectionStatus {
Disconnected,
Connected,
Reconnecting {
cause: DisconnectCause,
},
Rejected(ReasonCode),
}Expand description
The connection status of an MqttClient.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Disconnected
Not connected to any broker.
This is the initial state and the final state after a
stop call or when
reconnection is disabled and all attempts have been exhausted.
Connected
A CONNACK was received and the client is actively exchanging packets.
Reconnecting
The connection went down and the client is waiting before the next reconnection attempt.
Fields

cause: DisconnectCauseWhy the connection went down.
Rejected(ReasonCode)
The broker refused the connection with the given CONNACK reason code.
This is the final status when reconnection is disabled (or a fatal
rejection stopped it, see
ReconnectOptions::stop_on_fatal_rejection), or the status held
while backing off before another attempt.